import Vue from 'vue'
import Router from 'vue-router'
import AppIndex from '../views/home/AppIndex'
import RouterView from '../views/home/RouterView'
import {vaildJWT, GetUserAuthority} from "../utils/service/jwt";
import {getCookie, setCookie, deleteCookie} from "../utils/service/cookie";

Vue.use(Router)

export const defaultRoutes = [
  {
    path: '/index',
    name: 'AppIndex',
    component: AppIndex,
    children: [
      {
        path: '/home',
        name: 'Home',
        component: () => import('../views/homePage/Index'),
        meta: { title: '首页', icon: 'icon-menu icon-home', menuKey: "sy" },
      },
      {
        path: '/userManage',
        name: 'UserManage',
        component: RouterView,
        meta: { title: '用户管理', icon: 'icon-menu icon-yhgl', menuKey: "yhgl" },
        children: [
          {
            path: 'userList',
            name: 'UserList',
            component: () => import('../views/userManage/UserList'),
            meta: { title: '用户列表', menuKey: "yhlb" },
          },
          {
            path: 'userListDetail/:id',
            name: 'UserListDetail',
            component: () => import('../views/userManage/UserListDetail'),
            meta: { menuKey: "yhlb" },
            hidden: true
          },
          {
            path: 'userListEdit/:id',
            name: 'UserListEdit',
            component: () => import('../views/userManage/UserListDetail'),
            meta: { menuKey: "yhlb" },
            hidden: true
          },
          {
            path: 'userListAdd',
            name: 'UserListAdd',
            component: () => import('../views/userManage/UserListDetail'),
            meta: { menuKey: "yhlb" },
            hidden: true
          },
          {
            path: 'userApproval',
            name: 'UserApproval',
            component: () => import('../views/userManage/UserApproval'),
            meta: { title: '用户审批', menuKey: "yhsp" },
            hidden: true
          },
          {
            path: 'authManage',
            name: 'AuthManage',
            component: () => import('../views/userManage/AuthManage'),
            meta: { title: '权限管理', menuKey: "qxgl" },
          },
          {
            path: 'authManageAdd',
            name: 'AuthManageAdd',
            component: () => import('../views/userManage/AuthManageEdit'),
            meta: { menuKey: "qxgl" },
            hidden: true
          },
          {
            path: 'authManageDetail/:id',
            name: 'AuthManageDetail',
            component: () => import('../views/userManage/AuthManageEdit'),
            meta: { menuKey: "qxgl" },
            hidden: true
          },
          {
            path: 'authManageEdit/:id',
            name: 'AuthManageEdit',
            component: () => import('../views/userManage/AuthManageEdit'),
            meta: { menuKey: "qxgl" },
            hidden: true
          }
        ]
      },
      {
        path: '/logManage',
        name: 'LogManage',
        component: RouterView,
        meta: { title: '日志管理', icon: 'icon-menu icon-rzgl', menuKey: "rzgl" },
        children: [
          {
            path: 'userLoginLogs',
            name: 'UserLoginLogs',
            component: () => import('../views/logManage/UserLoginLogs'),
            meta: { title: '用户登录日志', menuKey: "yhdlrz" },
          },
          {
            path: 'sysOperationLog',
            name: 'SysOperationLog',
            component: () => import('../views/logManage/SysOperationLog'),
            meta: { title: '系统操作日志', menuKey: "xtczrz" },
          }
        ]
      },
      /* {
        path: '/sysConfigs',
        name: 'SysConfigs',
        component: RouterView,
        meta: { title: '系统设置', icon: 'icon-menu icon-xtsz', menuKey: "xtsz" },
        children: [
          {
            path: 'orgConfig',
            name: 'OrgConfig',
            component: () => import('../views/sysConfigs/OrgConfig'),
            meta: { title: '单位设置', menuKey: "dwsz" },
          },
        ]
      } */
    ]
  },
  {
    path: '/',
    redirect: '/home',
  }
]


const createRouter = () => new Router({
  scrollBehavior: () => ({ y: 0 }),
  routes: []
})

const router = createRouter()

export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

router.beforeEach((to, from, next) => {
  vaildJWT(getCookie("m_token")).then(res=>{
    if (res.code==="200") {
      if(getCookie('userInfo')==='') {
        setCookie('userInfo', JSON.stringify(res.data), 1)
      }
      next()
    }else {
      deleteCookie('m_token')
      deleteCookie('userInfo')
      localStorage.removeItem('authority')
      window.open(
        `https://geodatasvr.cn.smism.com/platform-entrance-s/#/login?url=https://geodatasvr.cn.smism.com/user_authentication/#/home`,
        "_self",
        "",
        true
      )
      // location.href = "http://47.101.207.123:8080/platform-rk/#/login?url=http://47.101.207.123:8080/user_authentication/#/home"
    }
  },error=>{
    deleteCookie('m_token')
    deleteCookie('userInfo')
    localStorage.removeItem('authority')
     window.open(
      `https://geodatasvr.cn.smism.com/platform-entrance-s/#/login?url=https://geodatasvr.cn.smism.com/user_authentication/#/home`,
      "_self",
      "",
      true
    )
    // location.href = "http://47.101.207.123:8080/platform-rk/#/login?url=http://47.101.207.123:8080/user_authentication/#/home"
  })
  // next()
})

export default router
